@@ -1,4 +1,4 @@
-/* $Id: keitai.c,v 1.22 2005/12/11 20:17:58 ichiro Exp $ */
+/* $Id: keitai.c,v 1.30 2005/12/11 21:40:01 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -50,82 +50,63 @@
 int
 keitai_start(struct tparam *th)
 {
-	char a1[IRC_MAX], a2[IRC_MAX], a3[IRC_MAX * 2], a4[IRC_MAX * 2];
-	char *s;
+	char channel[C_NAME];
 
 #ifdef DEBUG
 		printf("%s\r\n", th->l_buff);
 #endif
 	/* skip NOTICE messages */
-	if ((s = strstr(th->l_buff, "NOTICE"))) {
+	if (strstr(th->l_buff, "NOTICE")) {
 	}
 
 	/* catch PING messages */
-	if ((s = strstr(th->l_buff, "PING"))) {
+	if (strstr(th->l_buff, "PING"))
 		ping_recv(th);
-	}
 
 	/* catch NICK name */
-	if ((s = strstr(th->l_buff, "NICK"))) {
+	if (strstr(th->l_buff, "NICK"))
 		nick_recv(th);
-	}
 
 	/* detect JOIN channel */
-	if ((s = strstr(th->l_buff, "JOIN"))) {
-		sscanf(th->l_buff, ":%s JOIN :%[^,]", a1, a3);
-		if (a3[0] != '#') { /* for madoka4.2 */
-			sscanf(th->l_buff, ":%s JOIN %[^,]", a1, a3);
+	if (strstr(th->l_buff, "JOIN")) {
+		sscanf(th->l_buff, ":%*s JOIN :%[^,]", channel);
+		if (channel[0] != '#') { /* for madoka4.2 */
+			sscanf(th->l_buff, ":%*s JOIN %[^,]", channel);
 #ifdef DEBUG
 			printf("JOIN: madoka hack\n");
 #endif
 		}
-		join_recv(th, a3);
+		join_recv(th, channel);
 	}
 
-	if ((s = strstr(th->l_buff, "PART"))) {
+	if (strstr(th->l_buff, "PART"))
 		part_recv(th);
- 	}
 
 	/* catch PRIVMSGs */
-	if ((s = strstr(th->l_buff, "PRIVMSG"))) {
+	if (strstr(th->l_buff, "PRIVMSG"))
 		priv_recv(th);
-	}
 
 	/* catch QUIT */
-	if ((s = strstr(th->l_buff, "QUIT"))) {
+	if (strstr(th->l_buff, "QUIT")) {
 #ifdef DEBUG
 		printf("QUIT:%s\n", th->l_buff);
 #endif
 	}
 
 	/* detect TOPIC */
-	if ((s = strstr(th->l_buff, "332"))) {
-		if ((sscanf(th->l_buff, ":%s 332 %*s %s :%[^\n]",
-			a1, a2, a4)) == 3) {
-			topic_recv(th, "332", a2, a4);
-		}
-	} else if ((s = strstr(th->l_buff, "TOPIC"))) {
-		if ((sscanf(th->l_buff, ":%[^!]!%*s TOPIC %s :%[^\n]",
-			a1, a2, a4)) == 3) {
-			topic_recv(th, a1, a2, a4);
-		}
-	}
+	if (strstr(th->l_buff, "332") || strstr(th->l_buff, "TOPIC"))
+		topic_recv(th);
 
 	/* MODE */
-	if ((s = strstr(th->l_buff, "MODE"))) {
+	if (strstr(th->l_buff, "MODE")) {
 #ifdef DEBUG
 		printf("MODE:%s\n", th->l_buff);
 #endif
 	}
 
 	/* NAMES */
-	if ((s = strstr(th->l_buff, "353"))) {
-		if ((sscanf(th->l_buff, ":%*s 353 %s %*s %s :%[^\n]",
-			a2, a3, a4)) == 3) {
-			if (strcmp(th->real_nickname, a2) == 0)
-				names_recv(th, a3, a4);
-		}
-	}
+	if (strstr(th->l_buff, "353"))
+		names_recv(th);
 
 	return (0);
 }
@@ -222,7 +203,7 @@ int priv_recv(struct tparam *th)
 	}
 	th->history_count[ch_number]++;
 
-#ifdef DEBUG2
+#ifdef DEBUG
 	printf("%d: %s | %s\n", (th->history_count[ch_number] - 1), channel2,
 		th->data[ch_number][th->history_count[ch_number] - 1]);
 #endif
@@ -230,11 +211,20 @@ int priv_recv(struct tparam *th)
 	return (0);
 }
 
-int names_recv(struct tparam *th, char *channel, char *names)
+int names_recv(struct tparam *th)
 {
 	int n = 0;
-	char buf[IRC_MAX * 2];
-	char channel2[C_NAME];
+	char id[IRC_MAX];
+	char channel[C_NAME], channel2[C_NAME];
+	char names[IRC_MAX];
+
+	/* get NAMES */
+	if ((sscanf(th->l_buff, ":%*s 353 %s %*s %s :%[^\n]",
+		id, channel, names)) != 3)
+		return (1);
+
+	if (strcmp(th->real_nickname, id) != 0)
+		return (0);
 
 	/* channel;  #hoge:*.jp -> %hoge */
 	channel_encode(channel2, channel);
@@ -251,21 +241,33 @@ int names_recv(struct tparam *th, char *channel, char *names)
 	return (0);
 }
 
-int topic_recv(struct tparam *th, char *user, char *channel, char *topic)
+int topic_recv(struct tparam *th)
 {
 	int n = 0;
-	char buf[IRC_MAX * 2];
-	char channel2[C_NAME];
+	char topic[IRC_MAX * 2], buf[IRC_MAX * 2];
+	char channel[C_NAME], channel2[C_NAME];
 
+	/* zero clear */
 	memset(buf, 0, sizeof(buf));
+	memset(channel, 0, sizeof(channel));
 	memset(channel2, 0, sizeof(channel2));
 
+	/* get TOPIC */
+	if (strstr(th->l_buff, "332")) {
+		if ((sscanf(th->l_buff, ":%*s 332 %*s %s :%[^\n]",
+			channel, topic)) != 2)
+			return (1);
+	} else if (strstr(th->l_buff, "TOPIC")) {
+		if ((sscanf(th->l_buff, ":%*s TOPIC %s :%[^\n]",
+			channel, topic)) != 2)
+			return (1);
+	}
+
 	/* channel;  #hoge:*.jp -> %hoge */
 	channel_encode(channel2, channel);
 
 #ifdef DEBUG
-	printf("TOPIC:user=%s, channel=%s, topic=%s\n",
-		user, channel2, topic);
+	printf("TOPIC:channel=%s, topic=%s\n", channel2, topic);
 #endif
 	/* '<','>' ---> '&lt;','&gt;' */
 	ltgt_encode(buf, topic);
